<?php

namespace Mavabc\Communityoutreach\Policies;

use Litepie\User\Contracts\UserPolicy;
use Mavabc\Communityoutreach\Models\CommunityOutreach;

class CommunityOutreachPolicy
{

    /**
     * Determine if the given user can view the community_outreach.
     *
     * @param UserPolicy $user
     * @param CommunityOutreach $community_outreach
     *
     * @return bool
     */
    public function view(UserPolicy $user, CommunityOutreach $community_outreach)
    {
        if ($user->canDo('communityoutreach.community_outreach.view') && $user->isAdmin()) {
            return true;
        }

        return $community_outreach->user_id == user_id() && $community_outreach->user_type == user_type();
    }

    /**
     * Determine if the given user can create a community_outreach.
     *
     * @param UserPolicy $user
     * @param CommunityOutreach $community_outreach
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('communityoutreach.community_outreach.create');
    }

    /**
     * Determine if the given user can update the given community_outreach.
     *
     * @param UserPolicy $user
     * @param CommunityOutreach $community_outreach
     *
     * @return bool
     */
    public function update(UserPolicy $user, CommunityOutreach $community_outreach)
    {
        if ($user->canDo('communityoutreach.community_outreach.edit') && $user->isAdmin()) {
            return true;
        }

        return $community_outreach->user_id == user_id() && $community_outreach->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given community_outreach.
     *
     * @param UserPolicy $user
     * @param CommunityOutreach $community_outreach
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CommunityOutreach $community_outreach)
    {
        return $community_outreach->user_id == user_id() && $community_outreach->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given community_outreach.
     *
     * @param UserPolicy $user
     * @param CommunityOutreach $community_outreach
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CommunityOutreach $community_outreach)
    {
        if ($user->canDo('communityoutreach.community_outreach.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given community_outreach.
     *
     * @param UserPolicy $user
     * @param CommunityOutreach $community_outreach
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CommunityOutreach $community_outreach)
    {
        if ($user->canDo('communityoutreach.community_outreach.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
