<?php

namespace Mavabc\Communityoutreach\Providers;

use Illuminate\Support\ServiceProvider;

class CommunityoutreachServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'communityoutreach');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'communityoutreach');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('mavabc.communityoutreach', function ($app) {
            return $this->app->make('Mavabc\Communityoutreach\Communityoutreach');
        });

                // Bind CommunityOutreach to repository
        $this->app->bind(
            'Mavabc\Communityoutreach\Interfaces\CommunityOutreachRepositoryInterface',
            \Mavabc\Communityoutreach\Repositories\Eloquent\CommunityOutreachRepository::class
        );

        $this->app->register(\Mavabc\Communityoutreach\Providers\AuthServiceProvider::class);
                $this->app->register(\Mavabc\Communityoutreach\Providers\EventServiceProvider::class);
        
        $this->app->register(\Mavabc\Communityoutreach\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['mavabc.communityoutreach'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('mavabc/communityoutreach.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/communityoutreach')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/communityoutreach')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
